@@ -1,8 +1,8 @@
 from rich.prompt import Confirm
 from .core import is_existing_store_name, switch_to_alt_store
 from .messages import show_store_with_name_not_exists
-from cmdcheatsheet.config.consts import CURR_STORE_LOCATION_CONF
-from cmdcheatsheet.shared.models import CommandArgument, CommandDetails
+from ..config.consts import CURR_STORE_LOCATION_CONF
+from ..shared.models import CommandArgument, CommandDetails
 
 
 class SwitchToAltStore(CommandDetails):
