@@ -1,4 +1,4 @@
-from cmdcheatsheet.shared.display import display_error
+from ..shared.display import display_error
 
 
 def show_command_not_found():
